
# eRelax Vaillant
This module is used to control eRelax Vaillant or similar devices via netatmo cloud.

## Usage
```
define my_vaillant PythonModule erelax_vaillant <USER> <PASSWORD> [<STATION_NAME>]
```